==> flutter_kz_library-0.0.8.tar.gz: example/lib/src/screens/home/HomePage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';

class HomePage extends StatefulWidget {
  HomePage({Key key}) : super(key: key);

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  List _buildList() {
    List<Widget> listItems = List();

    for (int i = 0; i < 20; i++) {
      listItems.add(CardRoundRectangleBorderWidget(
          bolderColor: Colors.red,
          index: i,
          onLongPress: (index) {},
          onPressed: (index) async {},
          child: (index) => ListTile(
                title: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text('Title $i',
                        style: TextStyle(fontWeight: FontWeight.bold)),
                  ],
                ),
                trailing: Icon(Icons.chevron_right),
              )));
    }

    return listItems;
  }

  @override
  Widget build(BuildContext context) {
    return SliverViewListWidget(
      dataPinnedLeading: Icon(Icons.show_chart),
      dataActions: <Widget>[],
      backGroundColor: Colors.red,
      expandedHeightPercent: 16,
      dataPinnedHeader: Row(
        children: <Widget>[
          Expanded(child: Text('works')),
          Expanded(
              child: Text(
            '0',
            textAlign: TextAlign.right,
          ))
        ],
      ),
      dataBackground: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          ListTile(
            title: Text(
              'Projects',
              style: TextStyle(
                color: Colors.white,
                fontSize: 32.0,
                fontWeight: FontWeight.w700,
              ),
            ),
            subtitle: Text('You have 0 works',
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 18,
                )),
          ),
        ],
      ),
      dataList: _buildList(),
    );
  }
}

==> flutter_kz_library-0.1.1.tar.gz: example/lib/src/screens/home/HomePage.dart <==
import 'package:flutter/material.dart';
import 'package:flutter_kz_library/flutter_kz_library.dart';

class HomePage extends StatefulWidget {
  HomePage({Key key}) : super(key: key);

  @override
  _HomePageState createState() => _HomePageState();
}

class _HomePageState extends State<HomePage> {
  List _buildList() {
    List<Widget> listItems = List();

    for (int i = 0; i < 20; i++) {
      listItems.add(CardRoundRectangleBorderWidget(
          bolderColor: Colors.red,
          index: i,
          onLongPress: (index) {},
          onPressed: (index) async {},
          child: (index) => ListTile(
                title: Column(
                  crossAxisAlignment: CrossAxisAlignment.start,
                  children: <Widget>[
                    Text('Title $i',
                        style: TextStyle(fontWeight: FontWeight.bold)),
                  ],
                ),
                trailing: Icon(Icons.chevron_right),
              )));
    }

    return listItems;
  }

  @override
  Widget build(BuildContext context) {
    return SliverViewListWidget(
      dataPinnedLeading: Icon(Icons.show_chart),
      dataActions: <Widget>[],
      backGroundColor: Colors.red,
      expandedHeightPercent: 16,
      dataPinnedHeader: Row(
        children: <Widget>[
          Expanded(child: Text('works')),
          Expanded(
              child: Text(
            '0',
            textAlign: TextAlign.right,
          ))
        ],
      ),
      dataBackground: Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          ListTile(
            title: Text(
              'Projects',
              style: TextStyle(
                color: Colors.white,
                fontSize: 32.0,
                fontWeight: FontWeight.w700,
              ),
            ),
            subtitle: Text('You have 0 works',
                style: TextStyle(
                  color: Colors.white,
                  fontSize: 18,
                )),
          ),
        ],
      ),
      dataContent: Container(
        padding: EdgeInsets.symmetric(horizontal: 20.0),
        decoration: BoxDecoration(
          color: Colors.white,
          border: Border.all(width: 0, color: Colors.white),
          borderRadius: BorderRadius.only(
            topLeft: Radius.circular(20.0),
            topRight: Radius.circular(20.0),
          ),
        ),
        child: Column(
          children: _buildList(),
        ),
      )
    );
  }
}
